@@ -1,6 +1,6 @@
 import json
-from Node import Node
-from Document import Document
+from graphmanagerlib.Node import Node
+from graphmanagerlib.Document import Document
 
 def GetJsonFromFile(jsonPath):
     f = open(jsonPath, )
